@@ -1,17 +1,13 @@
-from bergen.extenders.base import BaseExtender
-from xarray.core.dataarray import DataArray
-from xarray.core.dataset import Dataset
 from bergen.registries.arnheim import get_current_arnheim
 import os
 import s3fs
 import xarray as xr
 
 
-class Array(BaseExtender):
-    extension = "array"
+class Array:
 
     def _getZarrStore(self):
-        settings = self.getSettings()
+        settings = get_current_arnheim().getExtensions("elements")
         s3_protocol = "http:"
         endpoint_url = s3_protocol + "//" + settings["path"]
 
