@@ -2,11 +2,12 @@ from bergen.query import DelayedGQL
 
 
 GET_REPRESENTATION = DelayedGQL("""
-query Representation($id: Int!){
+query Representation($id: ID!){
   representation(id: $id){
     id
     name
-    image
+    tags
+    variety
     store
     unique
     sample {
@@ -18,11 +19,12 @@ query Representation($id: Int!){
 """)
 
 CREATE_REPRESENTATION = DelayedGQL("""
-mutation Representation($sample: ID!, $name: String!){
-  createRepresentation(sample: $sample, name: $name){
+mutation Representation($sample: ID!, $name: String!, $tags: [String], $variety: RepresentationVarietyInput!){
+  createRepresentation(sample: $sample, name: $name, tags: $tags, variety: $variety){
     name
     id
-    image
+    variety
+    tags
     store
     unique
   
@@ -35,7 +37,8 @@ mutation Representation($id: ID!){
   updateRepresentation(rep: $id){
     name
     id
-    image
+    variety
+    tags
     store
     unique
   }
@@ -48,8 +51,9 @@ query Representation($name: String) {
   representations(name: $name) {
     id
     name
-    image
     store
+    variety
+    tags
     unique
     sample {
       id
